@@ -4,29 +4,26 @@
 #include <QIcon>
 #include <QQmlContext>
 
-#include <MauiKit3/Core/mauiapp.h>
+#include <MauiKit4/Core/mauiapp.h>
+#include <MauiKit4/Archiver/moduleinfo.h>
 
 #include <KAboutData>
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #include "../project_version.h"
 
-#include "code/compressedfile.h"
 #include "code/arca.h"
 
 //Useful for setting quickly an app template
 #define ORG_NAME "Maui"
 #define PROJECT_NAME "Arca"
 #define COMPONENT_NAME "arca"
-#define PROJECT_DESCRIPTION "Archive manager and explorer."
 #define PRODUCT_NAME "maui/arca"
 #define PROJECT_PAGE "https://mauikit.org"
 #define REPORT_PAGE "https://github.com/Nitrux/arca/issues/new"
 
 int main(int argc, char *argv[])
 {
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-
     QApplication app(argc, argv);
 
     app.setOrganizationName(QStringLiteral(ORG_NAME));
@@ -35,12 +32,12 @@ int main(int argc, char *argv[])
 
     KLocalizedString::setApplicationDomain(COMPONENT_NAME);
 
-    KAboutData about(QStringLiteral(COMPONENT_NAME), 
-                     QStringLiteral(PROJECT_NAME), 
-                     PROJECT_VERSION_STRING, 
-                     i18n(PROJECT_DESCRIPTION),
-                     KAboutLicense::LGPL_V3, 
-                    APP_COPYRIGHT_NOTICE, 
+    KAboutData about(QStringLiteral(COMPONENT_NAME),
+                     QStringLiteral(PROJECT_NAME),
+                     PROJECT_VERSION_STRING,
+                     i18n("Archive manager and explorer."),
+                     KAboutLicense::LGPL_V3,
+                    APP_COPYRIGHT_NOTICE,
                      QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(QStringLiteral("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
@@ -51,6 +48,9 @@ int main(int argc, char *argv[])
     about.setOrganizationDomain(PROJECT_URI);
     about.setProgramLogo(app.windowIcon());
 
+    const auto TData = MauiKitArchiver::aboutData();
+    about.addComponent(TData.name(), MauiKitArchiver::buildVersion(), TData.version(), TData.webAddress());
+
     KAboutData::setApplicationData(about);
     MauiApp::instance()->setIconName("qrc:/logo.svg");
 
@@ -62,7 +62,7 @@ int main(int argc, char *argv[])
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
-    const QUrl url(QStringLiteral("qrc:/main.qml"));
+    const QUrl url(QStringLiteral("qrc:/app/maui/arca/controls/main.qml"));
     QObject::connect(&engine, &QQmlApplicationEngine::objectCreated,
                      &app, [url](QObject *obj, const QUrl &objUrl) {
         if (!obj && url == objUrl)
@@ -73,7 +73,6 @@ int main(int argc, char *argv[])
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
     qmlRegisterSingletonInstance<Arca>(PROJECT_URI, 1, 0, "Arc", Arca::instance());
-    qmlRegisterType<CompressedFile>(PROJECT_URI, 1, 0, "CompressedFile");
 
     engine.load(url);
 
